==> igniteui-react-16.16.2.tgz: package/esm2015/lib/CalendarBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarBaseSelection_$type } from "./CalendarBaseSelection";
import { CalendarBaseWeekStart_$type } from "./CalendarBaseWeekStart";
/**
 * @hidden
 */
export let CalendarBase = /*@__PURE__*/ (() => {
    class CalendarBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.h = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.h;
        }
        set nativeElement(a) {
            this.h = a;
            this.e.d = this.h;
        }
        get c() {
            let ret_ = this.f.c("selection");
            ret_ = enumGetBox(CalendarBaseSelection_$type, EnumUtil.getEnumValue(CalendarBaseSelection_$type, EnumUtil.parse(CalendarBaseSelection_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarBaseSelection_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(CalendarBaseSelection_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("selection", value_);
        }
        get g() {
            let ret_ = this.f.c("showWeekNumbers");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.i("showWeekNumbers", value_);
        }
        get d() {
            let ret_ = this.f.c("weekStart");
            ret_ = enumGetBox(CalendarBaseWeekStart_$type, EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, EnumUtil.parse(CalendarBaseWeekStart_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(CalendarBaseWeekStart_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.f.i("weekStart", value_);
        }
        get j() {
            let ret_ = this.f.c("locale");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.i("locale", value_);
        }
        get a() {
            let ret_ = this.f.c("disabledDates");
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.f.i("disabledDates", value_);
        }
        get b() {
            let ret_ = this.f.c("specialDates");
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.f.i("specialDates", value_);
        }
    }
    CalendarBase.$t = /*@__PURE__*/ markType(CalendarBase, 'CalendarBase', BaseElement.$);
    return CalendarBase;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/CalendarBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarBaseSelection_$type } from "./CalendarBaseSelection";
import { CalendarBaseWeekStart_$type } from "./CalendarBaseWeekStart";
import { DateRangeDescriptor } from "./DateRangeDescriptor";
/**
 * @hidden
 */
export let CalendarBase = /*@__PURE__*/ (() => {
    class CalendarBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.h = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.h;
        }
        set nativeElement(a) {
            this.h = a;
            this.e.o = this.h;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get c() {
            let ret_ = this.f.n("selection");
            ret_ = enumGetBox(CalendarBaseSelection_$type, EnumUtil.getEnumValue(CalendarBaseSelection_$type, this.f.f(CalendarBaseSelection_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarBaseSelection_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(CalendarBaseSelection_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("selection", value_);
        }
        get g() {
            let ret_ = this.f.n("showWeekNumbers");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.v("showWeekNumbers", value_);
        }
        get d() {
            let ret_ = this.f.n("weekStart");
            ret_ = enumGetBox(CalendarBaseWeekStart_$type, EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, this.f.f(CalendarBaseWeekStart_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarBaseWeekStart_$type, ret_);
        }
        set d(a) {
            let value_ = enumGetBox(CalendarBaseWeekStart_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("weekStart", value_);
        }
        get j() {
            let ret_ = this.f.n("locale");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.v("locale", value_);
        }
        get a() {
            let ret_ = this.f.m("disabledDates", (a) => new DateRangeDescriptor());
            return ret_;
        }
        set a(a) {
            let value_ = a;
            this.f.v("disabledDates", value_);
        }
        get b() {
            let ret_ = this.f.m("specialDates", (a) => new DateRangeDescriptor());
            return ret_;
        }
        set b(a) {
            let value_ = a;
            this.f.v("specialDates", value_);
        }
    }
    CalendarBase.$t = /*@__PURE__*/ markType(CalendarBase, 'CalendarBase', BaseElement.$);
    return CalendarBase;
})();
